% Supplementary information to the manuscript
% "Closed-form solution for the edge vortex of a revolving plate"
% by Di Chen, Dmitry Kolomenskiy and Hao Liu.
%
% This matlab code reproduces figure 9(b) shown in the manuscript.
% It plots the theoretical circulation versus distance from the axis of
% rotation at different time instants.
% 
% Optimized for Matlab R2017a
%
clear all;
close all;

% Set defaults
set(0,'DefaultaxesFontSize',8);
set(0,'DefaulttextFontsize',8);
set(0,'DefaultaxesFontName','Times-Roman');
set(0,'DefaulttextFontName','Times-Roman');
set(0,'defaulttextinterpreter','latex')

% Chord length, m
c = 0.001;

% Kinematic viscosity, m^2/s
nu = 1.56e-5;

% Angular velocity, 1/s
Om = 5*260;

% Reference time scale
T = 2*pi/Om;

% Reynolds number Omega c^2 / nu
Re_Om_c = Om * c^2 / nu;

% Spanwise vorticity transport coefficient
Ksp = 0.078465589689730*sqrt(Re_Om_c);

% Radial position, normalized
r_norm = (0.25:0.25:5.75).';

% Number of time snapshots
nPT = 5;

% Time instants
t = [0.06 0.12 0.25 0.5 0.75]*T;

% Line labels
lbl = {'r-.' 'g-' 'm--' 'b-.' 'k-'};
leg = {'$\mathrm{Theory,~}t=0.06T$' '$0.12T$' '$0.25T$' ...
    '$0.5T$' '$0.75T$'};

% Initialize normalized circulation
Gam_norm_all = {0};

% Loop for all time instants
for j = 1:nPT
    % Acceleration time parameter
    tach = 0.167;
    % Dimensionless time 
    s = Om*t(j)/tach;
    % Substitutions
    if (s < pi)
        g = s-sin(s);
        gs = 1-cos(s);
        I = sin(2*s)/4+sin(s)-s*cos(s)-s/2;
    else
        g = 2*s-pi;
        gs = 2;
        I = pi/2;
    end
    % Normalized point vortex circulation    
    G1N = pi/(4*Ksp)^(1/3) * r_norm.^(4/3) * ...
        gs/2 * ( 1 - (1 + Ksp*tach*I/gs) * exp(-Ksp*tach*g) )^(1/3);
    % Normalized perpendicular distance to the vortex  
    z1N_re = 1/2^(7/3)/Ksp^(2/3)*r_norm.^(2/3) * ...
        ( 1 - (1 + Ksp*tach*I/gs) * exp(-Ksp*tach*g) )^(2/3);
    % Normalized half-plate circulation  
    GhpN = sqrt(2)*r_norm - ...
        G1N.*(1/2 + 1/pi*atan((1-2*z1N_re)./(2*sqrt(z1N_re))));
    % Sum of the above
    Gam_norm_all{j} = G1N + GhpN;        
end

% Cast a figure
h_fig = figure(1); 
set(h_fig,'Units','centimeters','Position',0.8*[2.5 7 9 7.0], ...
    'PaperPositionMode','auto');  
clf;

% Plot lines
for j = 1:nPT
    plot(r_norm,Gam_norm_all{j},lbl{j},'LineWidth',0.5); hold on;
end

% Annotate
axis([0 6 0 35]);
set(gca,'XTick',[0:1:6]);
xlabel('$r/c$');
ylabel('$\Gamma_\Sigma / \Omega c^2$');
hl = legend(leg,'Location','NorthWest');
set(hl,'Interpreter','Latex');
title('\rm{(}\it{b}\rm{)}');

% Print the figure
print('fig9b.eps','-depsc');

